@@ -15,89 +15,72 @@
 # limitations under the License.
 
 
-# Internal function to remove overlapping periods in cohorts
-# This is used as a helper inside other cohort manipulation functions
-# @param x A cohort table (dataframe, tbl_dbi, arrow table...) that may have overlapping periods
-# @return A dplyr query that collapses any overlapping periods. This is very similar to union.
 cohortCollapse <- function(x) {
-  checkmate::assert_true(methods::is(x, "tbl_dbi"))
-  checkmate::assert_subset(c("cohort_definition_id", "subject_id", "cohort_start_date", "cohort_end_date"), colnames(x))
-  checkmate::assertTRUE(DBI::dbIsValid(x$src$con))
 
+  if ( !(methods::is(x, "data.frame") || methods::is(x, "tbl_sql")) ) {
+    cli::cli_abort("x must be a local dataframe or tbl_sql, not {paste(class(x), collapse = ', ')})")
+  }
+
+  checkmate::assert_subset(c("cohort_definition_id", "subject_id", "cohort_start_date", "cohort_end_date"), colnames(x))
 
   # note this assumes all columns are fully populated and cohort_end_date >= cohort_start_date
-  # TODO do we need to confirm this assumption?
 
-  con <- x$src$con
-  min_start_sql <- dbplyr::sql(glue::glue('min({DBI::dbQuoteIdentifier(con, "cohort_start_date")})'))
-  max_start_sql <- dbplyr::sql(glue::glue('max({DBI::dbQuoteIdentifier(con, "cohort_start_date")})'))
-  max_end_sql <- dbplyr::sql(glue::glue('max({DBI::dbQuoteIdentifier(con, "cohort_end_date")})'))
-
-  x <- x %>%
+  x %>%
     dplyr::distinct() %>%
-    dplyr::mutate(dur = !!datediff("cohort_start_date",
-                                   "cohort_end_date")) %>%
-    dplyr::group_by(.data$cohort_definition_id, .data$subject_id, .add = FALSE) %>%
-    dbplyr::window_order(.data$cohort_start_date, .data$cohort_end_date,
-                         .data$dur) %>%
     dplyr::mutate(
-      prev_start = dplyr::coalesce(
-        !!dbplyr::win_over(
-          max_start_sql,
-          partition = c("cohort_definition_id", "subject_id"),
-          frame = c(-Inf, -1),
-          order = c("cohort_start_date", "dur"),
-          con = con),
-        as.Date(NA)),
-      prev_end = dplyr::coalesce(
-        !!dbplyr::win_over(
-          max_end_sql,
-          partition = c("cohort_definition_id", "subject_id"),
-          frame = c(-Inf, -1),
-          order = c("cohort_start_date", "dur"),
-          con = con),
-        as.Date(NA)),
-      next_start = dplyr::coalesce(
-        !!dbplyr::win_over(
-          min_start_sql,
-          partition = c("cohort_definition_id", "subject_id"),
-          frame = c(1, Inf),
-          order = c("cohort_start_date", "dur"),
-          con = con),
-        as.Date(NA))
+      cohort_start_date = as.Date(.data$cohort_start_date),
+      cohort_end_date   = as.Date(.data$cohort_end_date),
+      dur = !!datediff("cohort_start_date", "cohort_end_date")
     ) %>%
-    dplyr::ungroup() %>%
-    dplyr::compute()
-
-  x <- x %>%
     dplyr::group_by(.data$cohort_definition_id, .data$subject_id, .add = FALSE) %>%
-    dbplyr::window_order(.data$cohort_definition_id, .data$subject_id,
-                         .data$cohort_start_date, .data$dur) %>%
-    dplyr::mutate(groups = cumsum(
-      dplyr::case_when(is.na(.data$prev_start)  ~ NA,
-                       !is.na(.data$prev_start)  &&
-                         .data$prev_start <= .data$cohort_start_date &&
-                         .data$cohort_start_date <= .data$prev_end ~ 0L,
-                       TRUE ~ 1L)
-    ))
-
-  x <- x  %>%
-    dplyr::mutate(groups = dplyr::if_else(
-      is.na(.data$groups)  &&
-        .data$cohort_end_date >= .data$next_start,
-      0L, .data$groups
-    ))
-
-  x <- x %>%
-    dplyr::group_by(.data$cohort_definition_id,
-                    .data$subject_id, .data$groups, .add = FALSE) %>%
-    dplyr::summarize(cohort_start_date = min(.data$cohort_start_date, na.rm = TRUE),
-                     cohort_end_date = max(.data$cohort_end_date, na.rm = TRUE),
-                     .groups = "drop") %>%
-    dplyr::select("cohort_definition_id", "subject_id",
-                  "cohort_start_date", "cohort_end_date")
-
-  x
+    {
+      if (methods::is(x, "tbl_sql")) {
+        dbplyr::window_order(., .data$cohort_start_date, .data$dur, .data$cohort_end_date) %>%
+        dplyr::mutate(
+          running_end = !!dbplyr::win_over(
+            dbplyr::sql(paste0("MAX(", DBI::dbQuoteIdentifier(x$src$con, "cohort_end_date"), ")")),
+            partition = c("cohort_definition_id", "subject_id"),
+            order = c("cohort_start_date", "cohort_end_date"),
+            frame = c(-Inf, 0),
+            con = x$src$con
+          ),
+          prev_end = dplyr::lag(.data$running_end),
+          new_group = dplyr::if_else(
+            is.na(.data$prev_end),
+            0L,
+            dplyr::if_else(.data$cohort_start_date <= .data$prev_end, 0L, 1L)
+          )
+        ) %>%
+        dplyr::mutate(
+          groups = !!dbplyr::win_over(
+            dbplyr::sql(paste0("SUM(", DBI::dbQuoteIdentifier(x$src$con, "new_group"), ")")),
+            partition = c("cohort_definition_id", "subject_id"),
+            order = c("cohort_start_date", "cohort_end_date"),
+            frame = c(-Inf, 0),
+            con = x$src$con
+          )
+        )
+      } else {
+        dplyr::arrange(., .data$cohort_start_date, .data$dur, .data$cohort_end_date) %>%
+        dplyr::mutate(
+          running_end = as.Date(cummax(as.integer(.data$cohort_end_date))),
+          prev_end    = dplyr::lag(.data$running_end),
+          new_group   = dplyr::if_else(
+            is.na(.data$prev_end),
+            0L,
+            dplyr::if_else(.data$cohort_start_date <= .data$prev_end, 0L, 1L)
+          ),
+          groups = cumsum(.data$new_group)
+        )
+      }
+    } %>%
+    dplyr::group_by(.data$cohort_definition_id, .data$subject_id, .data$groups, .add = FALSE) %>%
+    dplyr::summarise(
+      cohort_start_date = min(.data$cohort_start_date, na.rm = TRUE),
+      cohort_end_date   = max(.data$cohort_end_date,   na.rm = TRUE),
+      .groups = "drop"
+    ) %>%
+    dplyr::select("cohort_definition_id", "subject_id", "cohort_start_date", "cohort_end_date")
 }
 
 table_refs <- function(domain_id) {
@@ -174,7 +157,11 @@ generateConceptCohortSet <- function(cdm,
   # check cdm ----
   checkmate::assertClass(cdm, "cdm_reference")
   con <- cdmCon(cdm)
-  checkmate::assertTRUE(DBI::dbIsValid(cdmCon(cdm)))
+
+  if (!methods::is(omopgenerics::cdmSource(cdm), "local_cdm")) {
+    checkmate::assertTRUE(DBI::dbIsValid(cdmCon(cdm)))
+  }
+
   checkmate::assert_character(name, len = 1, min.chars = 1, any.missing = FALSE, pattern = "[a-zA-Z0-9_]+")
 
   checkmate::assertTRUE("observation_period" %in% names(cdm))
@@ -182,7 +169,12 @@ generateConceptCohortSet <- function(cdm,
   # check name ----
   checkmate::assertLogical(overwrite, len = 1, any.missing = FALSE)
   checkmate::assertCharacter(name, len = 1, any.missing = FALSE, min.chars = 1, pattern = "[a-z1-9_]+")
-  existingTables <- listTables(con, cdmWriteSchema(cdm))
+
+  if (!methods::is(omopgenerics::cdmSource(cdm), "local_cdm")) {
+    existingTables <- listTables(con, cdmWriteSchema(cdm))
+  } else {
+    existingTables <- omopgenerics::listSourceTables(cdm)
+  }
 
   if (name %in% existingTables && !overwrite) {
     rlang::abort(glue::glue("{name} already exists in the CDM write_schema and overwrite is FALSE!"))
@@ -279,9 +271,9 @@ generateConceptCohortSet <- function(cdm,
                        is_excluded = FALSE)
   }
 
-  cohort_set_ref <- df |>
+  cohort_set_ref <- df %>%
     dplyr::select("cohort_definition_id", "cohort_name", "limit",
-                  "prior_observation", "future_observation", "end") |>
+                  "prior_observation", "future_observation", "end") %>%
     dplyr::distinct()
 
   # check target cohort -----
@@ -295,20 +287,31 @@ generateConceptCohortSet <- function(cdm,
    }}
 
   # upload concept data to the database ----
+
+
   tempName <- paste0("tmp", as.integer(Sys.time()), "_")
 
-  DBI::dbWriteTable(cdmCon(cdm),
-                    name = .inSchema(cdmWriteSchema(cdm), tempName, dbms = dbms(con)),
-                    value = df,
-                    overwrite = TRUE)
+  if (!methods::is(omopgenerics::cdmSource(cdm), "local_cdm")) {
+    DBI::dbWriteTable(cdmCon(cdm),
+                      name = .inSchema(cdmWriteSchema(cdm), tempName, dbms = dbms(con)),
+                      value = df,
+                      overwrite = TRUE)
+  } else {
+    cdm <- omopgenerics::insertTable(cdm, name = tempName, table = df, overwrite = TRUE)
+  }
+
 
   if (any(df$include_descendants)) {
     checkmate::assertTRUE("concept_ancestor" %in% names(cdm))
   }
 
   # realize full list of concepts ----
-  concepts <- dplyr::tbl(cdmCon(cdm), .inSchema(cdmWriteSchema(cdm), tempName, dbms = dbms(con))) %>%
-    dplyr::rename_all(tolower)
+  if (!methods::is(omopgenerics::cdmSource(cdm), "local_cdm")) {
+    concepts <- dplyr::tbl(cdmCon(cdm), .inSchema(cdmWriteSchema(cdm), tempName, dbms = dbms(con))) %>%
+      dplyr::rename_all(tolower)
+  } else {
+    concepts <- cdm[[tempName]]
+  }
 
   if (any(df$include_descendants)) {
     concepts <- concepts  %>%
@@ -320,10 +323,7 @@ generateConceptCohortSet <- function(cdm,
           dplyr::any_of(c("limit", "prior_observation", "future_observation", "end"))
         ) %>%
         dplyr::union_all(
-          dplyr::tbl(
-            cdmCon(cdm),
-            .inSchema(cdmWriteSchema(cdm), tempName, dbms = dbms(con))
-          ) %>%
+          concepts %>%
           dplyr::select(dplyr::any_of(c(
             "cohort_definition_id", "cohort_name", "concept_id", "is_excluded",
             "limit", "prior_observation", "future_observation", "end"
@@ -343,11 +343,15 @@ generateConceptCohortSet <- function(cdm,
     dplyr::compute()
 
   on.exit({
-    if (DBI::dbIsValid(cdmCon(cdm))) {
-      DBI::dbRemoveTable(cdmCon(cdm), name = .inSchema(cdmWriteSchema(cdm), tempName, dbms = dbms(con)))
-    }},
-    add = TRUE
-  )
+    if (!methods::is(omopgenerics::cdmSource(cdm), "local_cdm")) {
+
+      if (DBI::dbIsValid(cdmCon(cdm))) {
+        DBI::dbRemoveTable(cdmCon(cdm), name = .inSchema(cdmWriteSchema(cdm), tempName, dbms = dbms(con)))
+      }
+    } else {
+      cdm[[tempName]] <- NULL
+    }
+  }, add = TRUE)
 
   domains <- concepts %>% dplyr::distinct(.data$domain_id) %>% dplyr::pull() %>% tolower()
   domains <- domains[!is.na(domains)] # remove NAs
@@ -404,7 +408,7 @@ generateConceptCohortSet <- function(cdm,
                                                          !!dateadd(df$start_date, 1))) %>%
       # silently ignore cdm records where end date is before start.
       # Another reasonable option could be to set end to start if end is before start.
-      dplyr::filter(cohort_start_date <= .data$cohort_end_date)
+      dplyr::filter(.data$cohort_start_date <= .data$cohort_end_date)
   }
 
   if (length(domains) == 0) {
@@ -442,9 +446,6 @@ generateConceptCohortSet <- function(cdm,
         dplyr::inner_join(obs_period, by = "subject_id")
     }
 
-    # TODO remove this variable since it is confusing
-    cohort_start_date <- "cohort_start_date"
-
     cohortRef <- cohort %>%
       dplyr::inner_join(obs_period, by = "subject_id") %>%
       # TODO fix dplyr::between sql translation, also pmin.
@@ -460,8 +461,7 @@ generateConceptCohortSet <- function(cdm,
         .data$cohort_end_date > .data$observation_period_end_date ~ .data$observation_period_end_date,
         TRUE ~ .data$cohort_end_date)) %>%
       dplyr::select("cohort_definition_id", "subject_id", "cohort_start_date", "cohort_end_date") %>%
-      # TODO order_by = .data$cohort_start_date
-      {if (limit == "first") dplyr::slice_min(., n = 1, order_by = cohort_start_date, by = c("cohort_definition_id", "subject_id")) else .} %>%
+      {if (limit == "first") dplyr::slice_min(., n = 1, order_by = .data$cohort_start_date, by = c("cohort_definition_id", "subject_id")) else .} %>%
       cohortCollapse() %>%
       dplyr::mutate(cohort_start_date = as.Date(.data$cohort_start_date),
                     cohort_end_date = as.Date(.data$cohort_end_date)) %>%
@@ -469,12 +469,13 @@ generateConceptCohortSet <- function(cdm,
   }
 
   cohortCountRef <- cohort_set_ref  %>%
-    dplyr::left_join(cohortRef %>%
-    dplyr::group_by(.data$cohort_definition_id) %>%
-    dplyr::summarise(
-      number_records = dplyr::n(),
-      number_subjects = dplyr::n_distinct(.data$subject_id)) %>%
-    dplyr::collect(),
+    dplyr::left_join(
+      cohortRef %>%
+        dplyr::group_by(.data$cohort_definition_id) %>%
+        dplyr::summarise(
+          number_records = dplyr::n(),
+          number_subjects = dplyr::n_distinct(.data$subject_id)) %>%
+        dplyr::collect(),
     by = "cohort_definition_id")  %>%
     dplyr::mutate(number_records = dplyr::if_else(is.na(.data$number_records),
                                                   0L,
@@ -495,7 +496,7 @@ generateConceptCohortSet <- function(cdm,
       excluded_records = 0L,
       excluded_subjects = 0L)
 
-    cohortCodelistRef <- df  %>%
+    cohortCodelistRef <- df %>%
       dplyr::mutate(codelist_type = "index event",
                     concept_id = as.integer(.data$concept_id)) %>%
       dplyr::select("cohort_definition_id",
