@@ -262,7 +262,7 @@ if (Sys.getenv("CI_TEST_DB") == "") {
   dbToTest <- c(
     # "bigquery"
     # ,
-    "duckdb"
+    # "duckdb"
     # ,
     # "postgres"
     # ,
@@ -272,7 +272,7 @@ if (Sys.getenv("CI_TEST_DB") == "") {
     # ,
     # "snowflake"
     # ,
-    # "spark"
+    "spark"
   )
 
   } else {
